@@ -1,3 +1,7 @@
+#
+# $Id$
+#
+
 =head1 NAME
 
 AudioFile::Info::MP3::Tag - Perl extension to get info from MP3 files.
@@ -20,7 +24,7 @@ use Carp;
 
 use MP3::Tag;
 
-our $VERSION = '1.6.4';
+our $VERSION = '1.06';
 
 my %data = (artist => ['artist', 'TPE1'],
             title  => ['song', 'TIT2'],
@@ -47,7 +51,7 @@ sub DESTROY {
 sub AUTOLOAD {
   our $AUTOLOAD;
 
-  my ($sub) = $AUTOLOAD =~ /::(\w+)$/;
+  my ($pkg, $sub) = $AUTOLOAD =~ /(.+)::(\w+)/;
 
   die "Invalid attribute $sub" unless exists $data{$sub};
 
@@ -58,7 +62,7 @@ sub AUTOLOAD {
       my $tag = $data{$sub}[0];
       $frame->$tag($_[1]);
       $frame->write_tag;
-    }
+    } 
     if (my $frame = $_[0]->{obj}{ID3v2}) {
       my $tag = $data{$sub}[1];
       if (exists $frame->get_frame_ids->{$tag}) {
@@ -67,8 +71,8 @@ sub AUTOLOAD {
         $frame->add_frame($tag, $_[1]);
       }
       $frame->write_tag;
-    }
-  }
+    } 
+  } 
 
   if ($_[0]->{obj}{ID3v2}) {
     return ($_[0]->{obj}{ID3v2}->get_frame($data{$sub}[1]))[0];
@@ -93,13 +97,13 @@ by AudioFile::Info::new.
 
 =head1 AUTHOR
 
-Dave Cross, E<lt>dave@mag-sol.comE<gt>
+Dave Cross, E<lt>dave@dave.org.ukE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2003-2009 by Magnum Solutions Ltd. All rights reserved.
+Copyright 2003-2006 by Dave Cross
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =cut
